.. _dipy_developers:

Developers
================

The core development team consists of the following individuals:

- **Eleftherios Garyfallidis**, University of Cambridge, UK 
- **Ian Nimmo-Smith**, MRC Cognition and Brain Sciences Unit, Cambridge, UK
- **Matthew Brett**, University of California, Berkeley, CA
- **Bago Amirbekian**, University of California, San Fransisco, CA
- **Frank Yeh**, Carnegie Mellon University, Pittsburgh, PA
- **Christopher Nguyen**, University of California, Los Angeles, CA
- **Emanuele Olivetti**, NeuroInformatics Laboratory (NILab), Trento, Italy
- **Yaroslav Halchenco**, PBS Department, Dartmouth, NH
- **And your name here ...**

